mailr5402 - /1.3/generic_fns/pymol.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 08, 2008 - 10:27:
Author: bugman
Date: Tue Apr  8 10:27:16 2008
New Revision: 5402

URL: http://svn.gna.org/viewcvs/relax?rev=5402&view=rev
Log:
Updated the command() function to the new relax design.


Modified:
    1.3/generic_fns/pymol.py

Modified: 1.3/generic_fns/pymol.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/pymol.py?rev=5402&r1=5401&r2=5402&view=diff
==============================================================================
--- 1.3/generic_fns/pymol.py (original)
+++ 1.3/generic_fns/pymol.py Tue Apr  8 10:27:16 2008
@@ -146,18 +146,19 @@
     pymol.pipe_write("util.cbss(" + `id` + ", 'red', 'yellow', 'green')")
 
 
-def command(run, command):
-    """Function for sending PyMOL commands to the program pipe."""
-
-    # Arguments.
-    self.run = run
-
-    # Test if the run exists.
-    if not self.run in relax_data_store.run_names:
-        raise RelaxNoPipeError, self.run
+def command(command):
+    """Function for sending PyMOL commands to the program pipe.
+
+    @param command: The command to send to PyMOL.
+    @type command:  str
+    """
+
+    # Test if the current data pipe exists.
+    if not relax_data_store.current_pipe:
+        raise RelaxNoPipeError
 
     # Pass the command to PyMOL.
-    self.pipe_write(command)
+    pymol.pipe_write(command)
 
 
 def create_macro():




Related Messages


Powered by MHonArc, Updated Tue Apr 08 10:40:10 2008